import { Collapse } from "bootstrap";
import { onMounted, Ref, ref, watch } from "vue";

export function useCollapse(
  el: Ref<HTMLElement>,
  show: Ref<boolean>,
  config?: Record<string, string | boolean>
): Ref<Collapse> {
  const collapse = ref<Collapse>();

  watch(show, () => {
    if (show.value) {
      collapse.value?.show();
    } else {
      collapse.value?.hide();
    }
  });

  onMounted(() => {
    if (el.value instanceof HTMLElement) {
      collapse.value = new Collapse(el.value, config);
      el.value.addEventListener("hide.bs.collapse", () => {
        show.value = false;
      });
      el.value.addEventListener("show.bs.collapse", () => {
        show.value = true;
      });
    }
  });

  return collapse as Ref<Collapse>;
}
