import { Modal } from "bootstrap";
import { onMounted, Ref, ref, watch } from "vue";

export function useModal(el: Ref<HTMLElement>, show: Ref<boolean>): Ref<Modal> {
  const modal = ref<Modal>();

  watch(
    () => show.value,
    () => {
      if (show.value) {
        modal.value?.show();
      } else {
        modal.value?.hide();
      }
    }
  );

  onMounted(() => {
    if (el.value instanceof HTMLElement) {
      modal.value = new Modal(el.value);
      el.value.addEventListener("hidden.bs.modal", () => {
        show.value = false;
      });
      el.value.addEventListener("shown.bs.modal", () => {
        show.value = true;
      });
      document.body.appendChild(el.value);
    }
  });

  return modal as Ref<Modal>;
}
